@@ -664,3 +664,13 @@ sub Tk::Wizard::_page_taskList {
 
 
 1;
+
+=head1 AUTHOR
+
+Lee Goddard (lgoddard@cpan.org).
+
+=head1 COPYRIGHT
+
+Copyright (C) Lee Goddard, 11/2002 - 01/2008 ff.
+
+Made available under the same terms as Perl itself.
